from django.contrib import admin

from . import models


class SeriesAdmin(admin.ModelAdmin):
    model = models.Series

    prepopulated_fields = {
        'slug': ('title', ),
    }


admin.site.register(models.Series, SeriesAdmin)



# -*- coding: utf-8 -*-
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding field 'Series.slug'
        db.add_column('series_series', 'slug',
                      self.gf('django.db.models.fields.SlugField')(default='set-me', max_length=50),
                      keep_default=False)


    def backwards(self, orm):
        # Deleting field 'Series.slug'
        db.delete_column('series_series', 'slug')


    models = {
        'contenttypes.contenttype': {
            'Meta': {'ordering': "('name',)", 'unique_together': "(('app_label', 'model'),)", 'object_name': 'ContentType', 'db_table': "'django_content_type'"},
            'app_label': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'model': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        },
        'series.series': {
            'Meta': {'object_name': 'Series'},
            'description': ('django.db.models.fields.TextField', [], {}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'slug': ('django.db.models.fields.SlugField', [], {'max_length': '50'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '250'})
        },
        'series.seriesnode': {
            'Meta': {'object_name': 'SeriesNode'},
            'content_type': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['contenttypes.ContentType']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'object_id': ('django.db.models.fields.PositiveIntegerField', [], {}),
            'order': ('django.db.models.fields.IntegerField', [], {'default': '0'}),
            'series': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'nodes'", 'to': "orm['series.Series']"})
        }
    }

    complete_apps = ['series']


from django.contrib.contenttypes import generic
from django.contrib.contenttypes.models import ContentType
from django.db import models

# TODO: Refactor this into a generic utils app to remove the wells dep
from armstrong.core.arm_wells.querysets import GenericForeignKeyQuerySet


class Series(models.Model):
    title = models.CharField(max_length=250)
    description = models.TextField()
    slug = models.SlugField()

    def __unicode__(self):
        return self.title

    def get_items(self):
        return GenericForeignKeyQuerySet(self.nodes.all().select_related())

    @property
    def items(self):
        if not getattr(self, '_items', False):
            self._items = self.get_items()
        return self._items


class SeriesNode(models.Model):
    class Meta:
        ordering = ['order', ]

    series = models.ForeignKey(Series, related_name='nodes')

    order = models.IntegerField(default=0)
    content_type = models.ForeignKey(ContentType)
    object_id = models.PositiveIntegerField()
    content_object = generic.GenericForeignKey('content_type', 'object_id')



# -*- coding: utf-8 -*-
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding model 'Series'
        db.create_table('series_series', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('title', self.gf('django.db.models.fields.CharField')(max_length=250)),
            ('description', self.gf('django.db.models.fields.TextField')()),
        ))
        db.send_create_signal('series', ['Series'])

        # Adding model 'SeriesNode'
        db.create_table('series_seriesnode', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('series', self.gf('django.db.models.fields.related.ForeignKey')(related_name='nodes', to=orm['series.Series'])),
            ('order', self.gf('django.db.models.fields.IntegerField')(default=0)),
            ('content_type', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['contenttypes.ContentType'])),
            ('object_id', self.gf('django.db.models.fields.PositiveIntegerField')()),
        ))
        db.send_create_signal('series', ['SeriesNode'])


    def backwards(self, orm):
        # Deleting model 'Series'
        db.delete_table('series_series')

        # Deleting model 'SeriesNode'
        db.delete_table('series_seriesnode')


    models = {
        'contenttypes.contenttype': {
            'Meta': {'ordering': "('name',)", 'unique_together': "(('app_label', 'model'),)", 'object_name': 'ContentType', 'db_table': "'django_content_type'"},
            'app_label': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'model': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        },
        'series.series': {
            'Meta': {'object_name': 'Series'},
            'description': ('django.db.models.fields.TextField', [], {}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '250'})
        },
        'series.seriesnode': {
            'Meta': {'object_name': 'SeriesNode'},
            'content_type': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['contenttypes.ContentType']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'object_id': ('django.db.models.fields.PositiveIntegerField', [], {}),
            'order': ('django.db.models.fields.IntegerField', [], {'default': '0'}),
            'series': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'nodes'", 'to': "orm['series.Series']"})
        }
    }

    complete_apps = ['series']


from django.views import generic as views

from . import models


class DetailView(views.DetailView):
    model = models.Series

    def get_template_names(self, **kwargs):
        return [
            'armstrong/apps/series/specific/%s.html' % self.object.slug,
            'armstrong/apps/series/series_detail.html',
        ]
